// Encoder-to-buttons for attiny13 v1.0
// Licensed under Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International http://creativecommons.org/licenses/by-nc-sa/4.0/

#include "avr/io.h"
#include "avr/interrupt.h"
#include "util/delay.h"

volatile int lastEncoded = 0;

int lastMSB = 0;
int lastLSB = 0; 
 
int main(void)
	{
	DDRB = 0b00000011;			// pb0 and pb1 are outputs
	PORTB &= ~(1<<PB0);			// output "button" 1
	PORTB &= ~(1<<PB1);			// output "button" 2
	PORTB |= (1<<PB3);			// pull-up
	PORTB |= (1<<PB4);			// pull-up

	GIMSK = 0b00100000;			// Enable pin change interrupts
	PCMSK = 0b00011000;			// Enable pin change interrupt for PB3 and PB4
	sei();						// Turn on interrupts


	while (1)
		{
		_delay_ms(7);			// delay in case the output pulse is too short
	   	PORTB &= ~(1<<PB0);		// turn off outputs after pulse
		PORTB &= ~(1<<PB1);		//
		sei();
    	}
	}


ISR(PCINT0_vect)
	{
	cli();
	int MSB = (!(PINB & (1<<PINB3)));			// MSB = most significant bit
	int LSB = (!(PINB & (1<<PINB4)));			// LSB = least significant bit
 
	int encoded = (MSB << 1) |LSB;				// converting the 2 pin value to single number
	int sum  = (lastEncoded << 2) | encoded;	// adding it to the previous encoded value
 
	if(sum == 0b1101 || sum == 0b0100 || sum == 0b0010 || sum == 0b1011)	
  	    PORTB |= (1<<PB0);
     
  	if(sum == 0b1110 || sum == 0b0111 || sum == 0b0001 || sum == 0b1000)
  	    PORTB |= (1<<PB1);
     
	lastEncoded = encoded;						// store this value for next time
	}

